#
# spec file for package openSUSE-release-tools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __provides_exclude ^perl.*
%define source_dir openSUSE-release-tools
%define announcer_filename factory-package-news
Name:           openSUSE-release-tools
Version:        20180511.af4e85a
Release:        lp150.1.1
Summary:        Tools to aid in staging and release work for openSUSE/SUSE
License:        GPL-2.0-or-later AND MIT
Group:          Development/Tools/Other
Url:            https://github.com/openSUSE/openSUSE-release-tools
Source:         %{name}-%{version}.tar.xz
BuildArch:      noarch
# Requires sr#512849 which provides osc_plugin_dir.
BuildRequires:  osc >= 0.159.0
BuildRequires:  python-PyYAML
BuildRequires:  python-cmdln
BuildRequires:  python-colorama
BuildRequires:  python-lxml
BuildRequires:  python-pycurl
BuildRequires:  python-python-dateutil
BuildRequires:  python-pyxdg
BuildRequires:  python-urlgrabber
%if 0%{?is_opensuse}
# Testing only requirements installed for `make check`.
BuildRequires:  libxml2-tools
BuildRequires:  python-httpretty
BuildRequires:  python-mock
BuildRequires:  python-nose
%endif

# Spec related requirements.
%if 0%{?is_opensuse}
BuildRequires:  apache-rpm-macros
%else
%define apache_sysconfdir %{_sysconfdir}/apache2
%endif
BuildRequires:  apache2-devel
BuildRequires:  rsyslog
BuildRequires:  systemd-rpm-macros

Requires:       python-PyYAML
Requires:       python-cmdln
Requires:       python-colorama
Requires:       python-lxml
# issue-diff.py, legal-auto.py, and openqa-maintenance.py
Requires:       python-pycurl
Requires:       python-python-dateutil
Requires:       python-pyxdg
Requires:       python-requests
Requires:       python-urlgrabber

# bs_mirrorfull
Requires:       perl-Net-SSLeay
Requires:       perl-XML-Parser

# Spec related requirements.
Requires:       osclib = %{version}

# Avoid needlessly building on s390x and such in various repos.
# Must include noarch for older systems even though it makes no sense due to
# https://bugzilla.redhat.com/show_bug.cgi?id=1298668.
ExclusiveArch:  noarch x86_64

%description
Tools to aid in staging and release work for openSUSE/SUSE

The toolset consists of a variety of stand-alone scripts, review bots, osc
plugins, and automation aids.

%package devel
Summary:        Development requirements for openSUSE-release-tools
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       libxml2-tools
Requires:       python-httpretty
Requires:       python-mock
Requires:       python-nose

%description devel
Development requirements for openSUSE-release-tools to be used in conjunction
with a git clone of the development repository available from %{url}.

%package abichecker
Summary:        ABI review bot
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       osclib = %{version}

%description abichecker
ABI review bot for checking OBS requests.

%package announcer
Summary:        Release announcer
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements.

%description announcer
OBS product release announcer for generating email diffs summaries.

%package check-source
Summary:        Check source review bot
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements.
Requires:       osclib = %{version}
Requires(pre):  shadow

%description check-source
Check source review bot that performs basic source analysis and assigns reviews.

%package leaper
Summary:        Leap-style services
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       osclib = %{version}
# osrt-leaper-review needs check_maintenance_incidents.py
Requires:       %{name}-maintenance = %{version}
Requires(pre):  shadow

%description leaper
Leap-style services for non-Factory projects.

%package maintenance
Summary:        Maintenance related services
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements.
Requires:       osclib = %{version}
Requires(pre):  shadow

%description maintenance
Maintenance related services like incident check.

%package metrics
Summary:        Ingest relevant data to generate insightful metrics
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements.
Requires:       osclib = %{version}
Requires(pre):  shadow
# TODO Requires: python-influxdb, but package does not exist in Factory, but
# present in Cloud:OpenStack:Master/python-influxdb.
Recommends:     python-influxdb
Suggests:       grafana
Suggests:       influxdb

%description metrics
Ingest relevant OBS and annotation data to generate insightful metrics.

%package repo-checker
Summary:        Repository checker service
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements.
Requires:       osclib = %{version}
# repo_checker.pl
Requires:       build
Requires:       perl-XML-Simple
Requires(pre):  shadow

%description repo-checker
Repository checker service that inspects built RPMs from stagings.

%package staging-bot
Summary:        Staging bot services
Group:          Development/Tools/Other
BuildArch:      noarch
# devel-project.py
Requires:       %{name} = %{version}
Requires:       osc-plugin-staging = %{version}
# For supersede service.
Requires:       osc-plugin-check_dups = %{version}
Requires(pre):  shadow

%description staging-bot
Staging bot services and system user.

%package totest-manager
Summary:        Manages product ToTest repository
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements.
Requires:       osclib = %{version}
Requires:       python-openqa_client

%description totest-manager
Manages product ToTest repository workflow and openQA interaction

%package pkglistgen
Summary:        Generates package lists in 000product
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       obs-service-product_converter
Requires:       osclib = %{version}
Requires:       python-requests
Requires:       python-solv
# we use the same user as repo-checker
PreReq:         openSUSE-release-tools-repo-checker

%description pkglistgen
Generates package lists based on 000package-groups and puts them
in 000product, resp 000release-packages


%package -n osclib
Summary:        Supplemental osc libraries
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements, but for now base deps.
Requires:       %{name} = %{version}
Requires:       osc >= 0.159.0

%description -n osclib
Supplemental osc libraries utilized by release tools.

%package -n osc-plugin-check_dups
Summary:        OSC plugin to check for duplicate requests
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       osc >= 0.159.0

%description -n osc-plugin-check_dups
OSC plugin to check for duplicate requests, see `osc check_dups --help`.

%package -n osc-plugin-cycle
Summary:        OSC plugin for cycle visualization
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       osc >= 0.159.0

%description -n osc-plugin-cycle
OSC plugin for cycle visualization, see `osc cycle --help`.

%package -n osc-plugin-staging
Summary:        OSC plugin for the staging workflow
Group:          Development/Tools/Other
BuildArch:      noarch
# devel-project.py needs 0.160.0 for get_request_list(withfullhistory) param.
Requires:       osc >= 0.160.0
Requires:       osclib = %{version}

%description -n osc-plugin-staging
OSC plugin for the staging workflow, see `osc staging --help`.

%package -n osc-plugin-vdelreq
Summary:        OSC plugin to check for virtually accepted request
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       osc >= 0.159.0

%description -n osc-plugin-vdelreq
OSC plugin to check for virtually accepted request, see `osc vdelreq --help`.

%prep
%setup -q

%build
make %{?_smp_mflags}

%check
%if 0%{?is_opensuse}
# TODO openSUSE/openSUSE-release-tools#1221: decide how to handle integration tests
# make check
%endif

%install
%make_install \
  grafana_provisioning_dir="%{_sysconfdir}/grafana/provisioning" \
  oscplugindir="%{osc_plugin_dir}" \
  VERSION="%{version}"

%pre announcer
getent passwd osrt-announcer > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-leaper" osrt-announcer
exit 0

%postun announcer
%systemd_postun

%pre check-source
getent passwd osrt-check-source > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-check-source" osrt-check-source
exit 0

%postun check-source
%systemd_postun

%pre leaper
getent passwd osrt-leaper > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-leaper" osrt-leaper
exit 0

%postun leaper
%systemd_postun

%pre maintenance
getent passwd osrt-maintenance > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-maintenance" osrt-maintenance
exit 0

%postun maintenance
%systemd_postun

%pre metrics
getent passwd osrt-metrics > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-metrics" osrt-metrics
exit 0

%postun metrics
%systemd_postun
# If grafana-server.service is enabled then restart it to load new dashboards.
if [ -x /usr/bin/systemctl ] && /usr/bin/systemctl is-enabled grafana-server ; then
  /usr/bin/systemctl try-restart --no-block grafana-server
fi

%pre repo-checker
getent passwd osrt-repo-checker > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-repo-checker" osrt-repo-checker
exit 0

%postun repo-checker
%systemd_postun

%pre staging-bot
getent passwd osrt-staging-bot > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-staging-bot" osrt-staging-bot
exit 0

%postun staging-bot
%systemd_postun

%pre totest-manager
getent passwd osrt-totest-manager > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-totest-manager" osrt-totest-manager
exit 0

%postun totest-manager
%systemd_postun
if [ -x /usr/bin/systemctl ] ; then
  instances=($(systemctl list-units -t service --full | grep -oP osrt-totest-manager@[^.]+ || true))
  if [ ${#instances[@]} -gt 0 ] ; then
    systemctl try-restart --no-block ${instances[@]}
  fi
fi

%postun pkglistgen
%systemd_postun

%files
%defattr(-,root,root,-)
%doc README.asciidoc
%{_bindir}/osrt-biarchtool
%{_bindir}/osrt-bs_mirrorfull
%{_bindir}/osrt-build-fail-reminder
%{_bindir}/osrt-checknewer
%{_bindir}/osrt-check_source_in_factory
%{_bindir}/osrt-check_tags_in_requests
%{_bindir}/osrt-compare_pkglist
%{_bindir}/osrt-create_test_dvds
%{_bindir}/osrt-fcc_submitter
%{_bindir}/osrt-findfileconflicts
%{_bindir}/osrt-issue-diff
%{_bindir}/osrt-legal-auto
%{_bindir}/osrt-obs_clone
%{_bindir}/osrt-openqa-maintenance
%{_bindir}/osrt-rebuildpacs
%{_bindir}/osrt-requestfinder
%{_bindir}/osrt-status
%{_bindir}/osrt-sync-rebuild
%{_bindir}/osrt-unmaintained
%{_datadir}/%{source_dir}
%exclude %{_datadir}/%{source_dir}/abichecker
%exclude %{_datadir}/%{source_dir}/%{announcer_filename}
%exclude %{_datadir}/%{source_dir}/check_maintenance_incidents.py
%exclude %{_datadir}/%{source_dir}/check_source.pl
%exclude %{_datadir}/%{source_dir}/check_source.py
%exclude %{_datadir}/%{source_dir}/devel-project.py
%exclude %{_datadir}/%{source_dir}/leaper.py
%exclude %{_datadir}/%{source_dir}/manager_42.py
%exclude %{_datadir}/%{source_dir}/metrics
%exclude %{_datadir}/%{source_dir}/metrics.py
%exclude %{_datadir}/%{source_dir}/metrics_release.py
%exclude %{_bindir}/osrt-openqa-comments
%exclude %{_datadir}/%{source_dir}/pkglistgen.py
%exclude %{_datadir}/%{source_dir}/repo_checker.pl
%exclude %{_datadir}/%{source_dir}/repo_checker.py
%exclude %{_datadir}/%{source_dir}/suppkg_rebuild.py
%exclude %{_datadir}/%{source_dir}/totest-manager.py
%exclude %{_datadir}/%{source_dir}/osclib
%exclude %{_datadir}/%{source_dir}/osc-check_dups.py
%exclude %{_datadir}/%{source_dir}/osc-cycle.py
%exclude %{_datadir}/%{source_dir}/osc-staging.py
%exclude %{_datadir}/%{source_dir}/osc-vdelreq.py
%exclude %{_datadir}/%{source_dir}/update_crawler.py
%dir %{_sysconfdir}/openSUSE-release-tools

%files devel
%defattr(-,root,root,-)
# Non-empty for older products.
%doc README.asciidoc

%files abichecker
%defattr(-,root,root,-)
%{apache_sysconfdir}/vhosts.d/opensuse-abi-checker.conf.in
%{_datadir}/%{source_dir}/abichecker
%{_tmpfilesdir}/opensuse-abi-checker.conf
%{_unitdir}/opensuse-abi-checker.service

%files announcer
%defattr(-,root,root,-)
%doc %{announcer_filename}/README.asciidoc
%{_bindir}/osrt-announcer
%{apache_sysconfdir}/conf.d/%{announcer_filename}.conf.in
%{_datadir}/%{source_dir}/%{announcer_filename}
%config(noreplace) %{_sysconfdir}/openSUSE-release-tools/announcer
%config(noreplace) %{_sysconfdir}/rsyslog.d/%{announcer_filename}.conf
%{_unitdir}/osrt-announcer@.service
%{_unitdir}/osrt-announcer@.timer

%files check-source
%defattr(-,root,root,-)
%{_bindir}/osrt-check_source
%{_datadir}/%{source_dir}/check_source.pl
%{_datadir}/%{source_dir}/check_source.py
%{_unitdir}/osrt-check-source.service
%{_unitdir}/osrt-check-source.timer

%files leaper
%defattr(-,root,root,-)
%{_bindir}/osrt-leaper
%{_bindir}/osrt-leaper-crawler-*
%{_bindir}/osrt-manager_42
%{_bindir}/osrt-update_crawler
%{_datadir}/%{source_dir}/leaper.py
%{_datadir}/%{source_dir}/manager_42.py
%{_datadir}/%{source_dir}/update_crawler.py
%{_unitdir}/osrt-leaper-crawler@.service
%{_unitdir}/osrt-leaper-crawler@.timer
%{_unitdir}/osrt-leaper-manager@.service
%{_unitdir}/osrt-leaper-manager@.timer
%{_unitdir}/osrt-leaper-review.service
%{_unitdir}/osrt-leaper-review.timer
%config(noreplace) %{_sysconfdir}/openSUSE-release-tools/manager_42

%files maintenance
%defattr(-,root,root,-)
%{_bindir}/osrt-check_maintenance_incidents
%{_datadir}/%{source_dir}/check_maintenance_incidents.py
%{_unitdir}/osrt-maintenance-incidents.service
%{_unitdir}/osrt-maintenance-incidents.timer

%files metrics
%defattr(-,root,root,-)
%{_bindir}/osrt-metrics
%{_datadir}/%{source_dir}/metrics
%{_datadir}/%{source_dir}/metrics.py
%{_datadir}/%{source_dir}/metrics_release.py
# To avoid adding grafana as BuildRequires since it does not live in same repo.
%dir %attr(0750, root grafana) %{_sysconfdir}/grafana
%dir %{_sysconfdir}/grafana/provisioning
%dir %{_sysconfdir}/grafana/provisioning/dashboards
%dir %{_sysconfdir}/grafana/provisioning/datasources
%{_sysconfdir}/grafana/provisioning/dashboards/%{name}.yaml
%{_sysconfdir}/grafana/provisioning/datasources/%{name}.yaml
%{_unitdir}/osrt-metrics@.service
%{_unitdir}/osrt-metrics@.timer
%{_unitdir}/osrt-metrics-release@.service
%{_unitdir}/osrt-metrics-release@.timer

%files repo-checker
%defattr(-,root,root,-)
%{_bindir}/osrt-repo_checker
%{_datadir}/%{source_dir}/repo_checker.pl
%{_datadir}/%{source_dir}/repo_checker.py
%{_unitdir}/osrt-repo-checker.service
%{_unitdir}/osrt-repo-checker.timer
%{_unitdir}/osrt-repo-checker-project_only@.service
%{_unitdir}/osrt-repo-checker-project_only@.timer

%files staging-bot
%defattr(-,root,root,-)
%{_bindir}/osrt-devel-project
%{_bindir}/osrt-openqa-comments
%{_bindir}/osrt-suppkg_rebuild
%{_datadir}/%{source_dir}/devel-project.py
%{_datadir}/%{source_dir}/suppkg_rebuild.py
%{_unitdir}/osrt-staging-bot-check_duplicate_binaries@.service
%{_unitdir}/osrt-staging-bot-check_duplicate_binaries@.timer
%{_unitdir}/osrt-staging-bot-daily@.service
%{_unitdir}/osrt-staging-bot-daily@.timer
%{_unitdir}/osrt-staging-bot-devel-list.service
%{_unitdir}/osrt-staging-bot-devel-list.timer
%{_unitdir}/osrt-staging-bot-openqa-comments@.service
%{_unitdir}/osrt-staging-bot-openqa-comments@.timer
%{_unitdir}/osrt-staging-bot-regular@.service
%{_unitdir}/osrt-staging-bot-regular@.timer
%{_unitdir}/osrt-staging-bot-reminder.service
%{_unitdir}/osrt-staging-bot-reminder.timer
%{_unitdir}/osrt-staging-bot-supersede@.service
%{_unitdir}/osrt-staging-bot-supersede@.timer
%{_unitdir}/osrt-staging-bot-support-rebuild@.service
%{_unitdir}/osrt-staging-bot-support-rebuild@.timer

%files totest-manager
%defattr(-,root,root,-)
%{_bindir}/osrt-totest-manager
%{_datadir}/%{source_dir}/totest-manager.py
%{_unitdir}/osrt-totest-manager@.service

%files pkglistgen
%defattr(-,root,root,-)
%{_bindir}/osrt-pkglistgen
%{_datadir}/%{source_dir}/pkglistgen.py
%{_unitdir}/osrt-pkglistgen@.service
%{_unitdir}/osrt-pkglistgen@.timer

%files -n osclib
%defattr(-,root,root,-)
%{_datadir}/%{source_dir}/osclib
%{osc_plugin_dir}/osclib

%files -n osc-plugin-check_dups
%defattr(-,root,root,-)
%{_datadir}/%{source_dir}/osc-check_dups.py
%{osc_plugin_dir}/osc-check_dups.py

%files -n osc-plugin-cycle
%defattr(-,root,root,-)
%{_datadir}/%{source_dir}/osc-cycle.py
%{osc_plugin_dir}/osc-cycle.py

%files -n osc-plugin-staging
%defattr(-,root,root,-)
%{_datadir}/%{source_dir}/osc-staging.py
%{osc_plugin_dir}/osc-staging.py

%files -n osc-plugin-vdelreq
%defattr(-,root,root,-)
%{_datadir}/%{source_dir}/osc-vdelreq.py
%{osc_plugin_dir}/osc-vdelreq.py

%changelog
* Fri May 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180511.af4e85a:
  * dist/spec: bump copyright year.
  * dist/spec: sort requirements.
  * dist/spec: update to new license standard.
  * dist/spec: move ExclusiveArch up to apply to all packages instead of devel.
* Fri May 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.a8b760d:
  * dist/spec: exclusively build on x86_64 to avoid needless builds and OBS bugs.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.b4943dc:
  * osclib/conf: update nocleanup-packages post migration to new pkglistgen.
  * osclib/conf: change pkglistgen-include-suggested to False.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.ae00f10:
  * dist: provide osrt-staging-bot-check_duplicate_binaries@.service.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.846b2bd:
  * dist: provide openqa-comments service as part of staging-bot.
  * dist: package openqa-comments as executable.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.afbd03d:
  * systemd/leaper-crawler.service: wrap script with bash to handle colon.
  * dist/package/spec: leaper package requires maintenance.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.6fd17f1:
  * [oqamaint] Don't start and resolve incident job before is fully build
  * [oqamaint] Fix data for KGraft
* Wed May  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180509.90155fc:
  * osclib/comments: command_find: use MULTILINE mode.
  * osclib/comments: command_find: stupid \r line endings.
* Wed May  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180509.41bbae7:
  * manager_42: check if SLE-workarounds are no longer utilized and request removal.
* Wed May  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180509.324f7cc:
  * config/manager_42/Leap:15.0: update for Leap:15.0 source project reality.
  * config/manager_42/Leap:15.0: include from_proj in order to work properly.
  * config/manager_42/Leap:15.0: remove duplicate SLE-workarounds entry.
* Wed May  2 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180502.978881d:
  * [oqamaint] Take build number as last resort to avoid crash
  * [openqa-maintenance] Use to_xml method of Request object
  * [oqamaint] Do not export variables not necessary for scheduling
* Mon Apr 30 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180430.eb1d0be:
  * ReviewBot: runner: reload checker and reset memoize session caches.
  * osclib/memoize: provide memoize_session_reset().
* Fri Apr 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180427.1730947:
  * systemd/osrt-repo-checker-project_only@.timer: increase frequency to hourly.
  * repo_checker: project_only: store build hash and skip when unchanged.
* Fri Apr 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180427.adbbde2:
  * repo_checker: invoke whitelist_clean() as part of project_only.
  * repo_checker: whitelist_clean: provide interactive flag.
* Fri Apr 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180427.add0eb7:
  * [openqa-maintenance] Don't accept incidents waiting for build
  * osclib/check_duplicate_binaries: ignore any package arch that differs from arch.
  * osclib/check_duplicate_binaries: rewrite to use package_binary_list().
  * osclib/core: binary_src_debug: include nosrc as ignored arch.
  * osclib/core: package_binary_list: provide strip_multibuild option.
  * osclib/check_duplicate_binaries: drop unused imports post lnussel rework.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180426.2550cb4:
  * osclib/check_duplicate_binaries: ignore s/glibc.i686/glibc:i686/.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180426.2282f15:
  * metrics/grafana/dashboard: remove y-axis max from "Weekly Revisions".
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180426.2aba87c:
  * freeze_command: rebase staging project do not erase users data
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.abd03b3:
  * metrics: ingest_dashboard_config: rename seen to previous.
  * metrics: ingest_dashboard_config: initialize seen with last record keys.
  * metrics: ingest_dashboard_config: only fill missing values once.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.94fefaf:
  * metrics/grafana/dashboard: add release schedule annotation.
  * metrics/grafana/dashboard: include dashboard description.
  * metrics/grafana/dashboard: change all selectors to last.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.ade9313:
  * metrics: dashboard: drop dashboard measurement in favor of dashboard_revision.
  * metrics: dashboard: include revisions graph.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.adab26c:
  * repo_checker: provide whitelist_clean subcommand.
  * osclib/core: correct BINARY_REGEX by making it greedy.
* Wed Apr 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.8bb627d:
  * [oqamaint] Reset the hashes on every review round
  * [oqamaint] Fix re-reviewing requests
  * [oqamaint] Do not append to OS_TEST_ISSUES
  * [oqamaint] Look at all open release requests for Updates
  * [oqamaint] Reschedule Updates test if the list of incidents changed
  * [oqamaint] Remove wrong entries in json
* Wed Apr 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180424.2010288:
  * osclib/accept_command: avoid making empty commit to dashboard.
* Tue Apr 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180424.855f660:
  * unmaintained: utilize package_binary_list(exclude_src_debug).
  * osclib/core: package_binary_list(): provide exclude_src_debug option.
* Tue Apr 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.fe2e20a:
  * metrics/grafana: add dashboard.json.
  * metrics: ingest relevant dashboard files and extract metrics.
  * metrics: provide dashboard revision walking function and cache patterns.
  * metrics: instead of wiping cache place ephemeral patterns behind flag.
  * osclib/stagingapi: dashboard_content_load(): expose revision parameter.
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.6d46e97:
  * metrics/grafana/staging: move legend to right side on pie charts.
  * metrics/grafana/review: increase hieght on lists to accomodate size.
  * metrics/grafana/release: increase width to 100%% grid width.
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.884aa1f:
  * [openqa-maintenance] Add openSUSE Leap 15.0 configuration
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.dce40cb:
  * [oqamaint] Fix indentation
  * [oqamaint] Use reviewbot's comment API
  * [oqamaint] Add OS_TEST_ISSUES as openSUSE repo settings
  * [oqamaint] Make settings a hash instead of an array
  * [oqamaint] Remove symlinks - not necessary according to my experiments
  * [oqamaint] Create mesh compatible data for openSUSE
  * [oqamaint] Fetch the list of packages for openSUSE
  * [oqamaint] Fix openSUSE support
  * Rename openqa-maintenance2 to openqa-maintenance
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.750f091:
  * metrics/annotation: add openSUSE:Leap:15.0 schedule.
  * Handle the JeOS multibuild package for Factory:ARM:Live
  * leaper: update diff link to also link to package itself
  * leaper: fix link to SLE-workarounds
  * Handle Leap:15.0:Ports images_arm repository
* Thu Apr 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180419.3dcaf5c:
  * Handle more products for Factory:ARM
* Wed Apr 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180418.c725593:
  * devel-project: notify: utilize osclib.core.package_list_without_links().
  * osclib/core: provide package_list_without_links().
  * devel-project: remove unused imports.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.5b2296e:
  * dist/ci/obs-build-target: in include --always to git describe.
  * Makefile: package all executable files in bindir.
  * metrics_release: remove executable flag left over from development.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.e92d7bf:
  * check_tags_in_requests: replace check_action__default() with built-in.
  * legal-auto: replace check_action__default() with built-in.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.038cb94:
  * ReviewBot: disable comment handler for default action handler.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.b8337f4:
  * [openqabot-maintenance] Catch HTTPError when try get REPOHASH
  * [openqa-maintenance] SLE 12 SP2 LTSS
  * [openqa-maintenance] start HA/SES jobs only wheen are required
  * [openqa-mainteance] Add data for SES5
  * [openqa-maintenance] catch removed incident project
  * [openqa-maintenance] add missing arch for Live Patching apimap
  * [openqa-maintenance] Allow OS_TEST_ISSUES different than product prefix
  * [openqa-maintenance] Fix WSM and TCM issues data
  * [openqa-maintenance] Add correct issues for SLE-HA to apimap
  * [openqa-maintenance] Survive malformed repomd.xml
  * [openqa-maintenance] Add SLE-HA incidents
  * [openqa-maintenance] Allow and correctly use other distri from apimap.json
  * [openqa-maintenance] Add data for CAASP
  * [openqa-maintenance] Add data for KGraft on ppc64le
  * [openqa-maintenance] Start Incidents-Kernel flavour also for kernel packages
  * [openqa-maintenance] Add support for kGraft jobs
  * [openqa-maintenance] Rewrite of openqa-maintenace bot pt.1
  * [openqa-maintenance] Add apimap and incidents data for kGraft
  * [openqa-naintenance] Remove uneeded kGraft data
* Mon Apr 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180416.dc30723:
  * unmaintained: tool to find umaintained binaries sourced from SLE.
  * osclib/core: provide source_file_load() from StagingAPI.
* Fri Apr 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180413.71fd5fe:
  * pkglistgen: do_update_and_solve(): print exception and continue for all projects.
* Wed Apr 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180411.820d103:
  * issue-diff: utilize entity_mail() as adapted into osclib.core.
  * devel-project: provide notify sub-command.
  * osclib/util: provide mail_send(), modified from announcer.py.
  * osclib/core: provide entity_email(), modified from issue-diff.py.
* Fri Apr  6 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180406.ace73fe:
  * ttm: adjust regexp to include Snapshot
  * ttm: fix leap 15 docker image handling
* Thu Apr  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180405.e96a27a:
  * Staging2-DVD: Drop pattern gnome_laptop
  * create_test_dvds: Gcc7 staging project was resurrected
* Tue Apr  3 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180403.78ea7dd:
  * check_source: skip checks for packages without spec file
* Thu Mar 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180329.1ab84c3:
  * Change remaining usage of _product to 000product
  * leaper: set maintainer review early
  * leaper: also look into :Live subproject of Factory
* Thu Mar 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180329.9ad18cf:
  * Staging accept: run service in ports 000product
* Thu Mar 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180329.8097ab6:
  * conf: make sure variable is not None before do lower()
* Wed Mar 28 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180328.f195bc7:
  * repo-checker: Check delete requests for provided runtime dependencies
  * API: move fileinfo_ext[_all] from StagingAPI to core
* Mon Mar 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180326.b4c885d:
  * totest_manager: Also release openSUSE:Leap:15.0:Images/opensuse-leap-image
  * totest-manager: Tumbleweed moved to the new product builder
* Fri Mar 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180323.5d0c024:
  * leaper: allow comment override also on openSUSE
  * Add create_sle_weakremovers command
* Mon Mar 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180319.133d87b:
  * Change references to osc-plugin-factory to openSUSE-release-tools.
  * check_source: make use of ReviewBot request_default_return.
  * check_source_in_factory: allow repo-checker reviews.
* Sat Mar 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180317.88a6e97:
  * check_source: delete: place maintainer review check behind ignore_devel.
  * osclib/conf: SLE-15: set check-source-in-air-rename-allow to True.
  * check_source: provide in-air-rename-allow config setting.
* Fri Mar 16 2018 jberry@suse.com
- Point to new source location.
* Thu Mar 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180315.d11501f:
  * check_source: skip all checks for 00* packages
  * Use opensuse/tumbleweed in the Dockerfile
  * Avoid boolean dependencies for repo checker
* Thu Mar 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180314.3bd6833:
  * metrics_release: only works for openSUSE:Factory.
  * metrics: do not drop entire database, but instead measurements.
  * metrics: switch over to grafana 5.x provisioning.
  * metrics: remove TW snapshots graph from release dashboard.
  * metrics: migrate grafana dashboards to 5.x format.
* Mon Mar 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180312.9a26912:
  * pkglistgen: do_dump_solv(): include hash in update solv to avoid download.
  * pkglistgen: do_dump_solv(): utilize os.path.join().
* Mon Mar 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180312.054eef2:
  * ReviewBot: make interval work without tty
* Mon Mar 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180312.35e7c51:
  * services: Add Install section to totest-manager service
* Sun Mar 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180311.ad60562:
  * ReviewBot: don't crash if staging-group is None
  * check_source: make adding review team configurable
  * check_source: fix boolean option
  * pkglistgen: Fix reading boolean values
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.d001daf:
  * issue-diff: rename --config-dir as --cache-dir to be more accurate.
  * issue-diff: replace git sync functionality with osclib.git.
  * osclib/git: provide git utilities: clone() and sync().
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.fe4edd6:
  * Treat stagings differently
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.7484722:
  * pkglistgen: do_dump_solv: flush after write before reading back.
  * pkglistgen: do_dump_solv: verify primary repo gziped content sha256.
  * pkglistgen: do_dump_solv: use BytesIo instead of StringIO.
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.f20816d:
  * pkglistgen: Do not run local service check when committing to release package
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.f607883:
  * leaper: fix can_accept_review for combined user/group usage
  * create_test_Factory: No longer block kdelibs4-branding-upstream
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.d9773c3:
  * metrics: provide release metrics ingestion and dashboard.
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.568be98:
  * osclib/stagingapi: rename main_repo to cmain_repo.
  * osclib/stagingapi: rename delreq_review to cdelreq_review.
  * osclib/stagingapi: rename cstaging_nocleanup to cnocleanup_packages.
  * osclib/staging-api: lazy-load all config values to allow for placement in remote config.
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.17ebaaa:
  * ReviewBot: allow both group and user review
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.defd995:
  * osclib/conf: change priority to be string to work with ConfigParser.
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.3e83a1f:
  * leaper: do not decline SLE requests, but rather ask managers for input.
  * osclib/conf: configure SLE-15 leaper-override-group.
  * leaper: move review groups to osclib.conf.
* Wed Mar  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180307.f6eae67:
  * repo_checker: format what_depends_on as markdown bulleted list.
* Wed Mar  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180307.d30db7e:
  * repo_checker: provide comment command to skip-cycle for group.
  * repo_checker: utilize ReviewBot.comment_api instead of new instance.
  * ReviewBot: provide comment command override.
  * osclib/core: maintainers_get(): utilize new group_members() function.
  * osclib/core: provide group_members() function.
  * osclib/comments: provide command_find() for comment commands.
* Tue Mar  6 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180306.a9ec91f:
  * ReviewBot: do not bother commenting for unhandled request type.
* Thu Mar  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180301.bac6644:
  * fix a typo that currently breaks token authentication
* Tue Feb 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180227.adb01e2:
  * ttm: use dashboard_content_ensure()
* Fri Feb 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180223.e8c002d:
  * ttm: handle Leap 15 live images separately
  * requestfinder: make sure exclude-project is a list
  * requestfinder: fix exclude-user and add exclude-group
  * leaper: allow turning FORK into something else
* Fri Feb 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180223.af01909:
  * Staging2-DVD: should be Mesa-demo-x for glxgear test
* Thu Feb 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180222.db87a62:
  * Do not complain 000* package has defined in the two different ring
* Thu Feb 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180222.21777cc:
  * TW Staging media: Add Mesa-demo to Staging2 DVD for openQA test
* Thu Feb 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180222.009712a:
  * ttm: Follow package name changes of Tumbleweed live media
* Wed Feb 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180221.355c0b4:
  * Revert "staging: add exceptions for new 000* product files"
* Wed Feb 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180220.f56ccb8:
  * pkglistgen: solv_cache_update(): support update repo and 4 way merge.
  * pkglistgen: do_dump_solv(): support update repos.
  * pkglistgen: solv_merge(): allow array of solv files to merge.
  * pkglistgen: solv_merge(): skip when inputs are older than merged.
  * osclib/conf: leap: set download-baseurl-update.
* Tue Feb 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180220.945bf4f:
  * metrics: ingest_release_schedule(): disable for Tumbleweed until #1250.
  * metrics: update Leap config key to match osclib/conf post #1386.
* Tue Feb 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180220.fc7e60b:
  * pkglistgen: use set_namespaceproviders function
* Thu Feb 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180215.60cfab2:
  * osclib/conf: leap: repo_checker-arch-whitelist to x86_64.
* Tue Feb 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180213.c589ef1:
  * autopep8 to fix indenting
  * Move package hints into unsorted.yml
  * Support unneeded.yml as list of regular expressions
* Tue Feb 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180213.3e3f458:
  * conf: SLE-15: set pkglistgen-product-family-last to SLE-11:GA.
  * pkglistgen: expose pkglistgen-product-family-last config option.
  * osclib/util: project_list_family_prior(): provide last parameter.
  * osclib/util: project_list_family(): handle IBS SLE naming style.
  * pkglistgen: do_update_and_solve(): check for existence of :DVD instead of rings.
* Tue Feb 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180212.7f93dbe:
  * Skip automatic rebuild for more pattern packages
  * Avoid hitting the request limit
  * Fix rebuildpacs for armv6/armv7 architectures
* Mon Feb 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180212.87ab899:
  * leaper: don't check maintainer for other requests
* Fri Feb  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180209.ad077ab:
  * leaper: switch off maintainer review for updates from Factory
* Wed Feb  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180207.878b87b:
  * osc-staging: select: reword documentation to include XML reference.
  * osc-staging: select: mention additional supplemented request values.
  * osc-staging: select: mention quick strategy in documentation.
  * osc-staging: select: add filter-by example using hashtag in description.
* Wed Feb  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180206.56df1cf:
  * osclib/conf: include Leap for Factory during pkglistgen.
  * pkglistgen: include some hints about the difference between solv files.
  * pkglistgen: integrate drop list creation into update_and_solve.
  * pkglistgen: do_dump_solv(): handle old-style product repo format.
  * pkglistgen: do_create_droplist(): print to file when output_dir available.
  * pkglistgen: provide update_merge() to combine free and nonfree solv.
  * osclib/util: provide project_list_family* and project_version().
  * osclib/stagingapi: get_staging_projects(): utilize project_list_prefix().
  * osclib/core: provide project_list_prefix().
  * osclib/conf: add download-baseurl for Leap and Factory.
  * osclib/conf: support version in project pattern as value replacement.
* Wed Feb  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180206.faa028a:
  * osclib/conf: leap: incorporate proven unselect settings.
  * osclib/conf: leap: incorporate proven splitter settings.
* Tue Feb  6 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180206.453868a:
  * remove Leap 42.2 from tests
* Sat Feb  3 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180203.cd1fa5d:
  * CreatePackageDescr: ignore debuginfo.build deps for i-i-debuginfodeps* packages
* Thu Feb  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180201.10fd5ae:
  * pkglistegen: Fix overlap generation
* Wed Jan 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180131.b78d3b9:
  * build-faul-reminder: Small rewording of the 2nd mail
* Wed Jan 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180131.d88eefe:
  * adi: place :NonFree requests in separate adi with :NonFree path.
* Tue Jan 30 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180130.40c4c14:
  * status: fallback to request_age() even if no comment.
* Tue Jan 30 2018 jberry@suse.com
- Update to version 20180129.5a472eb:
  * osclib/core: request_age() return delta and handle Request object.
  * create_test_dvds: do not lock vim-data
  * fcc_submitter: skip revoked request
* Fri Jan 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180126.574cfe8:
  * status: provide exit code based on status.
  * status: provide initial implementation for checking bot status.
  * osclib/request_splitter: utilize osclib.core.request_age().
  * devel-project: utilize osclib.core.request_age().
  * osclib/core: provide request_age().
* Fri Jan 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180126.2c8c597:
  * osclib/accept: print todo from staging config after completion.
* Fri Jan 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.39c9cce:
  * check_source: add hint about how to whitelist a devel projects.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.a5dbcd1:
  * dist/spec: place config under %%config(noreplace) directive.
  * announcer: handle dot in build version detected from iso.
  * config/announcer: add openSUSE:Factory config.
  * announcer: provide defaults for sender, to, and relay.
  * config/announcer: create Leap 15.0 config from 42.3.
  * config/announcer: drop repeated keys in favor of final values.
  * config/announcer: include config used for Leap 42.3.
  * announcer: provide proper packaging and generic templated service.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.3cf74b3:
  * dist/ci/obs-deploy: replace `osc request list` with `osc api` call.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.753f6c7:
  * dist/ci/docker-compose-obs: print osc output on timeout for debugging.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.d383073:
  * repo_checker: skip packages for which not devel project exits.
  * repo_checker: project_only(): correct not published check.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.9a91597:
  * dist/ci/obs-deploy: only commit if new source revision.
  * dist/ci/obs-deploy: require greater than six lines changed to create request.
* Tue Jan 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180123.d074c5b:
  * Remove Vim config in favor of EditorConfig.
  * Add EditorConfig.
* Mon Jan 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180122.b5fe7e7:
  * dist/ci/obs-deploy: only bother making request if diff.
  * dist/ci/obs-deploy: limit `request list` by user to avoid source requests.
  * docs/pkglistgen: update in the wake of wrapper script rewrite.
* Fri Jan 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180119.a7c4bcf:
  * repo_checker: package_comments(): provide option to post on target package.
  * repo_checker: package_comments(): switch to devel_project_fallback().
  * repo_checker: package_comments(): support mutiple target projects.
  * ReviewBot: comment_write(): provide bot_name_suffix parameter.
  * repo_checker: package_comments(): include link to target package.
* Fri Jan 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180119.2d6b957:
  * check_source: add_role: utilize devel project fallback.
* Fri Jan 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180119.38fd846:
  * osclib/request_splitter: replace devel_project_get() with core.devel_project_fallback().
  * osclib/stagingapi: replace get_devel_project() with core.devel_project_get().
  * update_crawler: replace get_devel_project() with osclib.core.devel_project_get().
  * fcc_submitter: replace get_devel_project() with osclib.core.devel_project_get().
  * ReviewBot: replace get_devel_project() with osclib.core.devel_project_get().
  * osclib/core: devel_project_fallback(): do not fallback if openSUSE:Factory.
  * osclib/core: provide devel_project_fallback() based on request_splitter.
  * osclib/core: provide devel_project_get() adapted from ReviewBot.
  * news/web: allow dot in version.
  * cleanup_rings: Fix for 000product
  * cleanup_rings: first attempt to fix for multibuild
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180117.b6d80ea:
  * fcc_submitter: fix a regression from previous commit
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180117.e41b40e:
  * requestfinder: fix comment output
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180117.b335868:
  * pkglistgen: delete kiwis by scope
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180115.2da7981:
  * osclib/request_splitter: rework quick strategy to handle Leap 15.0 workflow.
  * obs_clone: reword comment in project_workaround() since not temporary.
  * obs_clone: clone rings.
  * obs_clone: handle project links.
  * osclib/request_splitter: allow special packages to be empty.
  * fcc_submitter: ignore multibuild flavor package when creating frozenlinks
  * fcc_submitter: move FCC project to :Staging:Factory:Candidates
  * new requestfinder tool
* Fri Jan 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180112.41846c5:
  * systemd/metrics: change service to be non-incremental and weekly.
  * metrics: provide --wipe-cache option.
* Thu Jan 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180111.54880d3:
  * dist/spec: license: s/and/AND/ to follow standard.
* Thu Jan 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180110.9ab0211:
  * obs_clone: workaround openSUSE:Factory meta revision 429 self reference.
  * obs_clone: set the exit code to 1 when HTTPError encountered.
* Wed Jan 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180110.453674c:
  * pkglistgen: typo locals vs locales
  * pkglistgen: add correct staging DVD repo
  * pkglistgen: use xdg.BaseDirectory
* Tue Jan  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180109.29108bd:
  * pkglistgen: do_update_and_solve: staging correct :DVD subproject append.
  * pkglistgen: first pass __file__ through realpath due to packaging symlink.
  * dist/spec: move pkglistgen.py under subpackage ownership.
  * dist/spec: add python-requests requirement were applicable.
* Tue Jan  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180109.09a98cd:
  * osclib/conf: intial SLE configuration for pkglistgen.
  * pkglistgen: update_and_solve: include step in output for debugging.
  * pkglistgen: update_and_solve: handle --dry for undelete_package().
  * pkglistgen: update_and_solve: include ignore_unresolvable and local options for solve.
  * pkglistgen: update_and_solve: set input_dir to group_dir for solve.
  * osclib/conf: correct Leap 15.0 default locales-from from - to . product.
  * systemd/pkglistgen: add update_and_solve subcommand.
* Tue Jan  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180109.2b037a0:
  * osclib/conf: allow devel projects to utilize tools that require conf.
  * osclib/conf: order config defaults by priority.
* Fri Jan  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180105.7eaed34:
  * Revert "osclib/conf: allow devel projects to utilize tools that require conf."
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.43dea82:
  * tests/ReviewBot_tests: add test_dryrun().
  * tests/ReviewBot_tests: add test_only_replace_none().
  * tests/ReviewBot_tests: add test_workflow() complex test.
  * tests/ReviewBot_tests: add test_basic_logger() as initial test.
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.656cba4:
  * tests/comment_test: add test_delete_nested().
  * tests/comment_test: add test_delete_batch().
  * tests/comment_test: add test_basic() against OBSLocal.
  * tests/comment_test: move COMMENT* constants to file level.
  * tests/OBSLocal: re-parse config and reset authentication when changing user.
  * tests/OBSLocal: setup test separate cookiejar.
  * tests/comment_tests: add test_comment_find().
  * tests/comment_tests: add test_remove_marker().
  * tests/comment_tests: add test_add_marker().
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.b0cd970:
  * osclib/conf: allow devel projects to utilize tools that require conf.
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.e1b5d75:
  * osclib/stagingapi: detect baselibs.conf in adi package and ensure archs enabled.
  * check_source: load target project config during check_action_delete().
  * osclib/stagingapi: load_file_content(): provide optional revision param.
  * osclib/stagingapi: load_file_content(): convert to makeurl() query builder.
* Tue Jan  2 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180102.98a659c:
  * manager42: ignore meta packages
  * manager42: refactor
  * manager42: don't turn dropped packages into fork
  * manager42: warn about inconsistent packages
  * reochecker: avoid accessing empty status
  * repo_checker: only update comment if published or message changed.
  * ReviewBot: comment_write(): provide info_extra_identical parameter.
  * fcc_submitter: handle multibuild package in build_succeeded package list
  * check_duplicate_binaries: better yaml
  * pkglistgen: migrate bash scripts to python.
  * osclib/stagingapi: provide is_staging_bootstrapped() from request_splitter.
  * ToolBase: provide -d alias for --debug for consistency.
* Tue Dec 26 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171226.96a3eec:
  * rebuildpacs: rebuild perf
* Wed Dec 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171220.ba8a357:
  * Be more forgiving with ttm ignore comments
* Tue Dec 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171219.ce7c0d9:
  * freeze_command: use result call to get proper multibuild package information for aggregatepac
* Tue Dec 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171219.55e468e:
  * Fix travis failure introduced with 3e5f3b137
  * Fix packaging after commit 3e5f3b137
  * Don't checkout master
  * Add 15.0 Ports to totest-manager
  * pkglistgen: Actually remove overlapping packages
  * Add support for non-x86_64 products (Leap 15.0/aarch64)
  * Scripts and templates to create stagings
  * systemd units: remove oneshot type
* Mon Dec 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171218.09707c0:
  * Update staging dvd template for firewalld and xfsprogs
  * rebuildpacs: ignore hdf5:serial
* Thu Dec 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171214.0fecf50:
  * osc-cycle: strip commas from package names
* Wed Dec 13 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171213.3dde523:
  * pkglistgen: Output the overlaping packages into overlap.group
* Tue Dec 12 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171212.bffe857:
  * totest-manager: Make sure internal object for notifications is always valid
* Fri Dec  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171208.d7c5a3e:
  * compare_pkglist: do not submit package if it has removed from target
  * pkglistgen: dump_solv function
  * pkglistgen: add droplist generator
  * pkglistgen: include locales and suggested
  * biarchtool: blacklist 000release-packages
  * biarchtool: also work for rings
  * biarchtool: blacklist patterns that are in ring1
  * biarchtool: fetch all packagemetas at once
* Tue Dec  5 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171205.1769209:
  * compare_pkglist: improve submission message
  * compare_pkglist: add feature to limits submission creating
  * compare_pkglist: fix a typo
* Mon Dec  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171204.4661a09:
  * rebuildpacs: Ignore some more multibuild packages
  * repochecker: filter out self requirement
  * repochecker: add --force and --limit-group options
* Mon Dec  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171204.86cd536:
  * compare_pkglist: fallback to old route if submitfrom and submitto has not defined
* Fri Dec  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171201.913531e:
  * osclib/cycles: only cache target project builddepinfo to avoid excessive cache.
  * osclib/cycles: drop _get_builddepinfo and _get_builddepinfo_cycles since unused.
  * Add more details to openQA job group description about current status
* Thu Nov 30 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171130.3b99a9d:
  * compare_pkglist: add more features
* Mon Nov 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171127.60cdcec:
  * check_source: Ignore download_files failure in some cases
* Mon Nov 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171127.3368dd5:
  * Implement namespace callback for locales
  * pkglistgen: Optionally include suggested packages too
  * fcc_submitter: update to Leap 15.0
  * ttm: Add support for SLE 15
* Wed Nov 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171122.ea9f948:
  * Split EDITOR environment variable to handle flags in prefix.
* Wed Nov 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171122.b428ed3:
  * compare_pkglist: Add --submit param to submit new package
* Tue Nov 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171121.734e384:
  * pkglistgen: need to expand link
  * pkglistgen: require python-solv
* Tue Nov 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171121.0d31ae5:
  * pkglistgen: Fix script name
  * Skip maintainer review for certain Leap 15 submissions
* Mon Nov 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171120.fc6eb19:
  * pkglistgen: require obs-service-product_converter
  * pkglistgen: add systemd units
  * pkglistgen: use new cache format of repo_checker
  * pkglistgen: process DVD subproject first
* Mon Nov 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171120.87649f1:
  * suppkg_rebuild: count Support tag also
* Wed Nov 15 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171115.6140695:
  * compare_pkglist: displays deleted package
  * compare_pkglist: misc improvements
* Sun Nov 12 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171112.b690943:
  * pkglistgen: fix up coolo's code
  * pkglistgen: Output overlapping packages as yaml
  * pkglistgen: Allow new recommended flag to take over recommends
  * pkglistgen: Ignore modules recursively
  * pkglistgen: Implement UNWANTED support
  * pkglistgen: Do not ignore recommendes from other modules
  * pkglistgen: Have update command exit 1 if it updated something
  * pkglistgen: Create an unsorted.yml and output duplications
* Fri Nov 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171110.5906e5c:
  * dist/spec: appease the exit status gods with || true.
  * dist/spec: restart totest-manager instances properly.
  * dist/spec: only run %%systemd_postun for oneshot services.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.f927c57:
  * metrics: rework to store points as named tuple and write in batches.
  * metrics: rework request pagination to provide as generator.
  * metrics: call ET.clear() to release unneeded memory used by search result.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.bcdea68:
  * Don't die on delete requests
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.3e191ca:
  * repo_checker: review failed stagings with only openQA failures.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.1efadc5:
  * metrics/grafana/review: include opensuse-review-team who graphs.
  * metrics/grafana/review: default to openSUSE:Factory.
  * metrics/grafana/review: disable annotations by default.
  * metrics/grafana/staging: "Project stats" to "Totals"
  * metrics/grafana/staging: remove 1s interval as it causes RAM issues.
  * metrics/grafana: standardize title prefix with 'OSRT: '.
  * dist/ci: grafana dir must be owned by grafana user since it writes lock.
  * dist/spec: correct metrics postun to reference systemctl by absolute path.
  * metrics: prefix release schedule file with source dir path.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.3d34370:
  * ttm: publish non-oss for Leap 15 too
* Fri Nov  3 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171103.593c900:
  * dist: provide metrics service and timer.
  * dist: install exported dashboards in grafana dashboard directory.
  * dist: include metrics.py in bindir.
  * dist: move package_name variable to Makefile.common.
* Fri Nov  3 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171103.f5bc6b6:
  * vdelreq: add to the package
  * osc vdelreq: new command lists pending virtually accepted delete request status
* Thu Nov  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171102.0a45aba:
  * accept_command: remove the ring package if it is 2nd specfile is removed
  * accept_command: force to accept the staging if --force parameter is given
* Wed Nov  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171031.d8cd193:
  * systemd/devel-list: allow three retry attempts to handle regular OBS crash.
* Wed Nov  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171031.0e1733f:
  * repo_checker: add newline to cycles comment to format properly.
  * repo_checker: project_only place dashboard update behind dryrun check.
  * repo_checker: project_only ensure project repository is published.
  * repo_checker: store and compare build hash to skip more aggressively.
* Tue Oct 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171031.c32b59b:
  * devel-project: override osc.core.search() to include withfullhistory for get_review_list().
* Sat Oct 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171028.9cded5c:
  * pkglistgen: also output suggested packages
* Fri Oct 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171027.63cde26:
  * pkglistgen: don't export skip_releases
* Wed Oct 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171025.42b8b4d:
  * osclib/memoize: include first argument, sometimes instance, in cache key.
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.32d1a97:
  * tests/OBSLocal: invoke scripts using `coverage` to include in report.
  * tests/OBSLocal: split out execute() to provide osc and generic versions.
  * tests/OBSLocal: include assertOBS() to clarify OBS status before test.
  * tests/OBSLocal: add email and include spaces in generated oscrc file.
  * tests/OBSLocal: rework OSCRC handling to use non-default file.
  * tests/OBSLocal: add workaround for obs.py leakage.
  * travis: before_cache: include -R in chmod .docker-tmp.
  * obs_clone: remove whole repositories rather than just path when fenced.
  * obs_clone: provide --cache feature.
  * osclib/cache: allow  ttl of 0 to prevent caching.
  * dist/spec: disable `make check` during %%check until integration tests resolved.
  * Exclude .open-build-service/ from docker, flake8, and git.
  * travis: provide local OBS setup and clone base data.
  * tests/devel_project: provide basic test against local OBS.
  * tests/OBSLocal: provide based class for testing against local OBS.
  * obs_clone: clone projects and dependencies between OBS instances.
  * devel-project: list: only remove self if in devel project list.
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.443b432:
  * osclib/conf: prefer already parsed conffile over OSC_CONFIG env variable.
  * tests/obs: move Cache.delete_all() after CACHE_DIR changed.
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.1c17971:
  * Blacklist new warnings introduced by flake8 3.5.0
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.737d39a:
  * pkglistgen: dont mirror debug packages
  * pkglistgen: skip one cycle when undeleting
* Sat Oct 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171021.9465b2f:
  * dist: add subpackage for pkglistgen
  * pkglisten: add some docu
  * pkglistgen: shell scripts to actually commit
* Sat Oct 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171020.0479513:
  * travis: chmod .docker-tmp so non-root can read for caching.
  * travis: extend cache timeout to 7 days.
  * travis: optimize `osc build` cache by removing build-root.
  * travis: enable pip cache.
  * travis: install realpath to allow docker-run to correctly mount volume.
* Sat Oct 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171020.ee34178:
  * travis: include all files instead of just osclib in coverage.
* Fri Oct 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171020.7d266d5:
  * Another set of low-noise flake8 cleanups
  * Parallelize flake8 run
* Fri Oct 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171019.24ea059:
  * dist/ci/docker-run: utilize throwaway credentials to workaround OBS issue.
  * dist/ci/osc-init: print OBS_API and OBS_USER for debugging.
  * dist/ci: use hidden directory .docker-tmp instead of HOME and cache on travis.
  * dist/ci: fallback to /public OBS API in the event of no OBS_PASS
  * dist/ci: provide OBS_API parameter.
  * travis: add distribution builds for Leap 42.3 and SLE-12-SP3.
  * dist/ci: rework spec.sh as obs-build-target using `osc build`.
  * dist/ci: extract common osc setup as osc-init and provide in /usr/bin.
  * dist/ci/Dockerfile: include obs-deploy in /usr/bin.
  * dist/ci: rename deploy.obs.sh to obs-deploy.
  * dist/ci/deploy: only commit if changes available to commit.
  * dist/ci/deploy: only add line if missing from _servicedata.
  * dist/ci/Dockerfile: switch to base tumbleweed image.
* Fri Oct 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171019.6b7fd1b:
  * Enable F405,F811 (Unused imports)
  * Add Flake8 travis infrastructure
  * Import all dependencies
  * White space / consistent usage of spaces / indentation of 4 fixes
  * Remove outdated script
* Thu Oct 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171019.be5b3ec:
  * devel-project: utilize get_request_list(withfullhistory) param provided by osc 0.160.0.
* Thu Oct 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171018.44e44a6:
  * Python 2.6+ / 3.x style except clauses
  * osclib/request_splitter: provide splitter-special-packages config variable.
  * osclib/request_splitter: reduce default list of special packages.
  * Rename checknewer to checknewer.py and fix Flake8 fallout
* Tue Oct 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171017.53f281e:
  * osc-staging: select -i: include remaining requests in comment.
  * osc-staging: select -i: s/merged/mergeable/ in stat comment.
* Tue Oct 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171017.1168d47:
  * Fix undefined variables 'release'
* Tue Oct 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171017.7058f07:
  * check_source: decline the delete request if duplicated
* Fri Oct 13 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171013.406f870:
  * pkglistgen: initial work for openSUSE
  * pkglistgen: make --repositories option use an array
  * pkglistgen: add --ignore-unresolvable and --ignore-recommends options
* Fri Oct 13 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171013.b00a8f5:
  * osclib/stagingapi: get_staging_projects(): provide include_dvd option.
  * check_source: print message if checking devel project.
  * check_source: move all relevant flags to config to work properly without flags.
  * ttm: update for Leap 15.0
  * osclib: provide ConfigCommand and expose via osc-staging.
  * repo_checker: utilize staging configuration for whitelist additions.
  * repo_checker: filter empty whitelist entries.
  * osclib/stagingapi: set_prj_pseudometa(): only change if different.
  * osclib/freeze: clear staging config during freeze as well.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.a2ba667:
  * dist: provide check-source subpackage.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.73cec11:
  * dist: provide maintenance subpackage.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.3ed4156:
  * dist: rework totest-manager subpackage to provide new style service.
  * dist/spec: add python-openqa_client as Requires for totest-manager.
  * dist/spec: totest-manager: reword to avoid dollar sign.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.f50ea95:
  * dist: provide leaper services and related configuration.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.de533a2:
  * dist: provide staging-bot subpackage for related services.
  * dist/spec: include project_only repo-checker service in pre/post.
  * dist: provide staging-bot-devel-list service (changed from leaper).
  * dist: include suppkg_rebuild in staging-bot subpackage.
  * dist: include supersede service in staging-bot subpackage.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.02e5000:
  * staging: add exceptions for new 000* product files
* Mon Oct  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171009.afbe149:
  * check_source: Ensure the source and destination package name matches
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.e1c7377:
  * dist/ci/deploy: handle expanded links during target project loookup.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.4b7fb2f:
  * dist/ci/deploy: wait for service to complete before create submit request.
  * dist/ci/deploy: automatically detect target project and package.
  * dist/ci/deploy: pipe `osc sr --diff` to cat to ensure same behavior manually run.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.49fa091:
  * travis: include OBS_TARGET_PROJECT env variable during deploy script.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.e6d2ffc:
  * dist/ci/deploy: create submit request if none currently exists.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.e8e1a3d:
  * Initial metrics ingestion, processing, write to influxdb, and grafana dashboards.
  * docs/metrics.md: initial documentation of metrics workflow.
  * dist/spec: create metrics sub-package.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.9621116:
  * check_source: drop unnecessary dest from add_option().
  * check_source: drop inaccurate "with > 8 diff" from --review-team option.
  * check_source: interpret "None" as python None for review-team and repo-checker.
  * check_source: lookup staging group using StagingAPI rather than flag.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.b325f15:
  * dist: provide repo-checker sub-package with binary in path, service, and user.
  * repo_checker: project_only(): correct result_comment() usage.
  * dist/spec: include perl script requirements.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.b129a13:
  * ReviewBot: comment_write(): add info_extra parameter.
  * ReviewBot: comment_write(): add overview documentation.
  * ReviewBot: comment_write(): pre-truncate for correct comparison.
  * ReviewBot: comment_write() no need to str() since None is exits above.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.a63d00c:
  * leaper: ignore 404
* Wed Oct  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171004.d163170:
  * maintbot: no maintainer review for SLE15 submissions
  * compare_pkglist: up to Leap 15.0 and SLE15
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.0087bc6:
  * Initial version of pkglistgen
  * Handle groups files also
  * Exclude missing packages
  * Solve based on explicit package list
  * Implement extra and discard
  * Solve more groups
  * Add options for input and output directories
  * Warn about supplements
  * Add all devel packages
  * Write unsorted packages
  * Don't abort on unresolvable
  * Catch missing arch specific packages
  * Always output all archs - even if empty
  * Remove duplicated packages during merge and autopep
  * Support silents
  * Use project instead of FACTORY
  * Solve the packages one by one instead of a group
  * Output devel packages per module
  * Generic OUTPUT handling
  * Generate errors into group comments
  * Generate development packages into group comments
  * Generate recommends (requires new python-solv)
  * Lock all binaries duplicated between repos - the first one wins
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.655a959:
  * conf: given default value to main_repo
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.167e744:
  * conf: given default value to delreq_review
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.a306181:
  * virtually accept: virtually accept the delete request
  * tests: fix testsuite for virtually accept
* Thu Sep 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170928.3bbeacd:
  * adi_command: do not checking adi staging status if there is no selected_requests
  * Include CLEANUP => 1 during temp directory creation in perl scripts.
* Thu Sep 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170920.4011159:
  * osclib/stagingapi: accept_status_comment(): avoid making comments for empty projects.
  * osclib/adi: include force=True when invoking delete_project().
* Wed Sep 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170920.0167a82:
  * totest-manager: Adapt zSystems to new productbuilder
* Mon Sep 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170918.035c367:
  * Disable ppc64le for now in Tumbleweed stagings
* Sat Sep 16 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170916.af9750d:
  * rm_from_prj: always use the origin project path to set_review()
* Fri Sep 15 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170915.6b1fad5:
  * stagingapi: refactor get_sub_packages() to support adi package
  * stagingapi: rm_from_prj() remove the main package in the last
  * stagingapi: submit_to_prj() create sub-package for adi request
* Thu Sep 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170913.92a3a28:
  * osclib/list: only present submit and delete requests in main list.
  * osclib/list: rework change_devel_requests to include set_bugowner.
  * osclib/request_finder: restrict to submit and delete request types.
* Mon Sep 11 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170911.3c1a264:
  * suppkg_rebuild: VMInstall is also valid on build service
* Mon Sep 11 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170911.2c899cf:
  * Remove local config for sle15 - it's remote
* Fri Sep  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170908.4077149:
  * Generate minimals with set compression
* Fri Sep  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170907.ca3c504:
  * [openqa-maintenance bot] fix accidentaly removed wrong line
  * stagingapi: carry over build state during supersede.
  * leaper: fix iterating through list
* Tue Sep  5 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170905.bd162b9:
  * Schedule incidents earlier
  * Only schedule one setting per target for now
  * add ltss
  * Add comment
  * Refresh incident comment
  * one more
  * Activate sp3
  * Fix variable name
  * Clone flavors
  * move the test loop into review
  * Do not schedule incidents twice
  * Skip kgraft target
  * move variable
  * Fix comments
  * Fix duplicated posts
  * Convert MINIMALS to set type
  * Remove usage of temporary files
* Mon Sep  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170904.2bbaa62:
  * totest-manager: Prevent old tests in same build blocking release with "latest=1"
* Mon Sep  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170904.c261049:
  * freeze_command: update product version for openSUSE only
* Sat Sep  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170902.bedca4c:
  * osclib/request_splitter: for SLE, fallback to openSUSE:Factory devel projects.
  * osclib/list: remove SUSE:SLE from hide_source now that devel groupings are used.
  * osclib/list: strip openSUSE.org: prefix from source projects to reduce verbosity.
  * Do not use direct flag for images
  * dist/package/spec: include version on osc Requires.
* Fri Sep  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170901.7c18d96:
  * Fix typo in bootstrap
* Thu Aug 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170831.b6c17fe:
  * osclib/stagingapi: lazy-load nocleanup-packages to allow for placement in remote config.
* Thu Aug 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170831.819da53:
  * ReviewBot: downgrade message about skipping duplicate review to debug.
  * ReviewBot: comment_write(): skip posting empty comments extracted from handler.
  * repo_checker: rename package-whitelist to binary-whitelist to be more accurate.
* Thu Aug 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170831.266f398:
  * travis: install libxml2-utils which provides xmllint.
* Wed Aug 30 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170830.68da325:
  * osclib/stagingapi: create_adi_project(): add :Staging passthru project.
* Wed Aug 30 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170829.ddb1395:
  * leaper: fix syntax error
  * leaper: avoid comments about unhandled request types
* Tue Aug 29 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170829.7357c5f:
  * SUSE: wants to build test dvds on 'local' workers
* Tue Aug 29 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170829.73b803a:
  * osclib/conf: do not disable remote config for SLE-15.
* Mon Aug 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170828.ed70089:
  * totest-manager: follow another live media setup change (no multibuild)
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.ca2db71:
  * totest-manager: do not attempt to put/post in --dry mode
  * totest-manager: Follow changes in Tumbleweed for the new live image setup
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.4ea3820:
  * dist/package/spec: utilzie %%osc_plugin_dir provided by osc post sr#512849.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.1d5c197:
  * stagingapi: Fix typo in _frozenlinks
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.a2eb80c:
  * accept: call accept_other_new() for all projects instead of just openSUSE.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.bf5ae3d:
  * repo_checker: only bother to parse if --post-comments.
  * repo_checker: move result_comment() headers into respective check methods.
  * repo_checker.pl: support multiple directories to check.
  * repo_checker: replace separate ignore methods with new algorithm.
  * osclib/conf: set staging-dvd-archs to empty for SUSE:* projects.
  * stagingapi: provide staging_walk() to cleanly handle :DVD subproject.
  * core: add memoize(session=True) to package_binary_list().
  * repo_checker: rework to handle multiple stagings per group (ie :DVD).
  * cycle: cycles() rename group parameter to staging to better reflect usage.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.2aae21d:
  * repo_checker: delete: explicitly indicate build requirement.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.a0a461f:
  * repo_checker: delete: do not decline instead ignore.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.c0ede24:
  * ReviewBot: comment_write(): place debug_key at the end for consistency.
  * ReviewBot: comment_write(): pull dryrun protected bit out individually.
  * ReviewBot: comment_write(): provide only_replace option.
  * repo_checker: post passed comment only if previous failed comment.
  * commentapi: provide truncate() and apply during add_comment().
  * repo_checker: package_comments(): drop truncation in favor of commentapi.
  * cycle: remove ugly ignore code from _get_builddepinfo_graph().
  * repo_checker.pl: ensure that parser does not bleed over to other sections.
  * repo_checker: use <pre> instead of ``` to avoid html entity escaping.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.8338287:
  * ReviewBot: simplify logger format.
* Thu Aug 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.7bbd005:
  * Use configured staging group for adi
* Thu Aug 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.adeb4c4:
  * Freeze Cmd: Implement freezing adi staging project
* Wed Aug 23 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170823.7502d6a:
  * stagingapi: avoid making an empty package-diff comment.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.55aeefa:
  * check_source: remove DIFFCOUNT algorithm and instead always add review_team.
  * check_source: rename perl and asciidoc to match name.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.2873a27:
  * core.owner_fallback(): check if startswith() instead of equal.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.09b046f:
  * ReviewBot: get_devel_project(): correct error handling to only allow 404.
  * ReviewBot: add_review(): remove left-over print() line.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.9bd2789:
  * stagingapi: Ensure the links is valid before processing
  * Add amarok to test-2 DVD
  * Remove sw_management_kde pattern from test-2 DVD
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.f230438:
  * dist/ci/Dockerfile: include `dup` before `in` to handle major base changes.
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.bf1662b:
  * ReviewBot: add_review(): raise exception instead of returning boolean.
  * ReviewBot: add_review(): provide allow_duplicate parameter and default of False.
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.54fcc90:
  * FccSubmitter: drop add_review() since never used and handled by other bots.
  * repo_checker: ignore non-existant binaries during lookup.
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.52cce8d:
  * switch to php7 in staging project
  * totest-manager: update Kubic name to openSUSE-Tumbleweed-Kubic
  * Staging DVDs: add x86 pattern to the media
  * suppkg_rebuild: Clean up supportpkg list also
* Mon Aug 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170814.8711b45:
  * check_source: change repo_checker default to new OBS username.
* Fri Aug 11 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170811.1cefbfc:
  * update-crawler: handle devel projects
* Tue Aug  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170808.c994bc8:
  * update crawler: latest_packages across instances
* Mon Aug  7 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170807.a64d27c:
  * Catch more errors, fixes
  * Fix biarch logic to make --force work
  * Update blacklist and whiteliste
  * Don't use product filter by default
  * Add libjpeg62-turbo to whitelist
  * add openSUSE-EULAs to blacklist
  * warn about linked packages
  * Remove leftover debug statements
  * Refactor getting file list
  * Speed up duplicate binaries check
* Mon Aug  7 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170807.2c08e40:
  * The first steps toward sle15 :)
* Fri Aug  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170804.072d1eb:
  * ReviewBot: comment_write(): support package.
  * osclib/core: provide BINARY_REGEX named group pattern and utilize.
  * osclib/core: add package to BinaryParsed tuple.
  * osclib/core: provide package_binary_list() to efficiently obtain binary to package map.
  * repo_checker: package_whitelist() does not need to support group splitting to find product.
  * repo_checker: provide optional parsing of install check output and mapping to package.
  * repo_checker: provide --post-comments option on project_only subcommand.
  * repo_checker: truncate long messages to avoid crashing OBS.
  * ReviewBot: comment_write(): include target in debug message when too similar.
* Wed Aug  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170802.cdde2bf:
  * repo_checker: add whitelist for adoption phase.
  * osclib/cycle: remove extra leading slash.
  * repo_checker: point to repo_checker file instead of old installcheck in project comment.
* Wed Aug  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170802.99df9c5:
  * leaper: transition from SLE-12-SP3 and Leap:42.3 to SLE-15 and Leap:15.0.
* Tue Aug  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170731.ad89a77:
  * dist/ci/Dockerfile: drop hard-coded mirror now that Tumbleweed issues resolved.
* Tue Aug  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170731.a5e3143:
  * repo-checker.pl: replace [^-]* with [^-]+ as it is more accurate.
  * repo-checker.pl: drop old debug lines.
  * Rename repo-checker.pl to repo_checker.pl to be consistent.
  * repo_checker.pl: switch from multi-line regex to single line and full.
  * repo_checker.pl: s/INSTALL/CONFLICTS/ for file pointer for more clarity.
  * repo_checker.pl: rework installcheck parsing like fileconflicts to resolve bugs.
* Fri Jul 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170728.1ecdcfd:
  * check_source: add devel review for delete request using MaintenanceChecker logic.
  * stagingapi: provide dashboard_content_{load,save,ensure}() and utilize.
  * repo_checker.pl: allow empty $repodir allowing just a project-wide check.
  * repo_checker: provide project_only subcommand to write result to installcheck.
* Fri Jul 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170728.03ba255:
  * Factory test dvd: upgrade to postgresql96
* Thu Jul 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170726.b7cff32:
  * osc-cycle: ignore invalid packages
* Thu Jul 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170724.4d5ba92:
  * openqa-maintenance: update data for schedule 12sp3 jobs
* Wed Jul 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170719.e4c11a6:
  * dist/ci/Dockerfile: add obs-service-set_version based on changes made for Factory.
* Wed Jul 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170719.00c88d1:
  * ReviewBot: provide staging_api() from repo_checker.
  * check_source: utilize project config to allow for remote entries.
  * cache: unquote() all URLs before processing to ensure correctness.
* Wed Jul 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170719.0a0bec5:
  * devel-project: get(): utilize osc.core.search() and improve xpath loop.
  * devel-project: provide maintainer command to check for relevant groups.
* Tue Jul 18 2017 jberry@suse.com
- Change set_version service to be disabled instead of buildtime.
  The change will appease the source check for Factory.
* Mon Jul 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170717.ce00330:
  * dist/spec: add missing osc requires.
  * dist/spec: include %%defattr on all %%files entries.
  * travis: include OBS_EMAIL environment variable when deploying.
  * dist/spec: utilize obs_scm renaming which properly includes version in source.
  * travis: target proper home in openSUSE:Tools for deployment.
  * dist/ci/Dockerfile: include obs-service-{download_files,format_spec_file} for deployment.
  * dist/ci/deploy.obs.sh: include apiurl in general so email is used during service run.
* Mon Jul 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170713.262d988:
  * Makefile & disc/spec: include version in installed osc-staging plugin.
  * travis: include list email address in changes entry during deployment.
* Mon Jul 17 2017 jberry@suse.com
- Change _service to rename in obs_scm instead of tar which handles
  rename properly.
- Correct previous change entries email address.
* Fri Jul 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170713.0a84043:
  * dist/ci/deploy.obs.sh: remove previous source.
* Fri Jul 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170713.bc8cb75:
  * travis: add deployment to OBS package on master branch commit.
* Tue Jul 11 2017 jberry@suse.com
- Initial package.
